function clusters = ihb_GetClusters
%
% patch for SPM2: A. Ischebeck, 07/2005
% overwrite the old version within in the TSU toolbox with this file
%
% Orientations: TSU works with the significant voxels given by SPM,
% so Orientation should be the ok, namely its the same 
% as the data appear in SPM results (-x = left).
%
%----------------------------------------------------------------------------------
% FORMAT clusters = ihb_getClusters
% Get cluster information (use [SPM,VOL,xX,xCon,xSDM] = spm_getSPM;)
%----------------------------------------------------------------------------------
%   01.03.01    Sergey Pakhomov
%   01.08.01    last modified
%   03.10.01    Modification to remove continue
%----------------------------------------------------------------------------------
% clusters          - array of structs with fields:
%
% Common to all clusters in the set
% 
% isSpmCluster      - 1 if got from SPM data; 0 - if constructed by 
%                     symmetrical or intersection
% title             - title for comparison (string) (SPM.title)
% hThreshold        - height threshold (SPM.u)
% voxSize           - voxel dimensions {mm} - column vector (VOL.VOX)
%
% specific for every cluster
% name              - name of the cluster
% numVox            - number of voxels in cluster
% Z                 - minimum of n Statistics {filtered on u and k} (1 x num_vox)
% XYZmm             - location of voxels {mm} (3 x num_vox)
% pVoxelLev         - corrected p for max value in cluster
% pClustLev         - corrected p for given cluster (cluster level)
%
% Talariach volume
% xTal  - x Talariach coordinates ready for contourslice & isosurface
% yTal  - y Talariach coordinates ready for contourslice & isosurface
% zTal  - z Talariach coordinates ready for contourslice & isosurface
% vTal  - Talariach volume values ready for contourslice & isosurface
% xMin, yMin, zMin, xMax, yMax, zMax - bounding box in mm for Talariach
%----------------------------------------------------------------------------------
%   10.04.01    Sergey Pakhomov
%   01.08.01    last modified
%----------------------------------------------------------------------------------
%----------------------------------------------------------------------------------
% Check existance of figures used by spm_getSPM
%----------------------------------------------------------------------------------
dflFileName = ihb_FileFolderName('dfl');
load(dflFileName, 'ihbdfl_spm_fig_Interactive');
load(dflFileName, 'ihbdfl_spm_fig_SelFileWin');
load(dflFileName, 'ihbdfl_spm_fig_ConMan');
hFigInteractive = findobj('Type', 'figure', 'Tag', ihbdfl_spm_fig_Interactive);
hFigSelFileWin = findobj('Type', 'figure', 'Tag', ihbdfl_spm_fig_SelFileWin);
hFigConMan = findobj('Type', 'figure', 'Tag', ihbdfl_spm_fig_ConMan);
%----------------------------------------------------------------------------------
% Get SPM information
%----------------------------------------------------------------------------------
[SPM,xSPM] = spm_getSPM;    % gendert fr spm2!
%----------------------------------------------------------------------------------
% Delete figures used by spm_getSPM if they were created during above call
%----------------------------------------------------------------------------------
if isempty(hFigInteractive) 
    delete(findobj('Type', 'figure', 'Tag', ihbdfl_spm_fig_Interactive)); 
end;
if isempty(hFigSelFileWin) 
    delete(findobj('Type', 'figure', 'Tag', ihbdfl_spm_fig_SelFileWin)); 
end;
if isempty(hFigConMan) 
    delete(findobj('Type', 'figure', 'Tag', ihbdfl_spm_fig_ConMan)); 
end;
%----------------------------------------------------------------------------------
if size(xSPM.XYZ, 2) == 0          % gendert fr spm2!
    clusters = [];
    h = warndlg('No voxels survive height threshold','Warning');
    delete(h);
    return;
end
A = spm_clusters(xSPM.XYZ);            % gendert fr spm2!
numClust = max(A);
clusters = [];
%----------------------------------------------------------------------------------
% Main cluster loop
%----------------------------------------------------------------------------------
load(dflFileName, 'ihbdfl_min_size_to_draw');
load(dflFileName, 'ihbdfl_tal_x_vox', 'ihbdfl_tal_y_vox', 'ihbdfl_tal_z_vox');
hWait = waitbar(0,'Preparing cluster data. Please wait...');
nTotalVox = size(A, 2);
nTotalProcessed = 0;

for curClust = 1:numClust
    %--------------------------------------------------------------------
    % Check current cluster size and skip if too small
    %--------------------------------------------------------------------
    a = find(A == curClust);
    if (size(a, 2) < ihbdfl_min_size_to_draw) | (size(a, 2) < xSPM.k)           % gendert fr spm2!
        nTotalProcessed = nTotalProcessed + size(a, 2);
        waitbar(nTotalProcessed/nTotalVox);
    else
        cl = ihb_DefineCluster;
        %--------------------------------------------------------------------
        % General cluster data
        %--------------------------------------------------------------------
        cl.isSpmCluster = 1;
        cl.title = xSPM.title;                   % gendert fr spm2!
        cl.hThreshold = xSPM.u;                  % gendert fr spm2!
        cl.voxSize = xSPM.VOX;                   % gendert fr spm2!
        %--------------------------------------------------------------------
        % Cluster specific data from SPM (MNI space)
        %--------------------------------------------------------------------
        cl.name = strcat(cl.title, '_', mat2str(size(a, 2)));
        cl.numVox = size(a, 2);   
        cl.Z = xSPM.Z(a);                          % gendert fr spm2!
        cl.XYZmm = xSPM.XYZmm(:,a);                % gendert fr spm2!
        cl.pVoxelLev = spm_P(1, 0, max(cl.Z), xSPM.df, xSPM.STAT, xSPM.R, xSPM.n);                % gendert fr spm2!
        cl.pClustLev = spm_P(1, cl.numVox/prod(xSPM.FWHM), xSPM.u, xSPM.df, xSPM.STAT, xSPM.R, xSPM.n);           % gendert fr spm2!
        %====================================================================
        % Talariach volume related data
        %====================================================================
        clOut = ihb_UpdateClusterTalVoxSize(cl, nTotalVox, nTotalProcessed);
        nTotalProcessed = nTotalProcessed + clOut.numVox;  
        clusters = [clusters, clOut];
    end;
end
close(hWait);
