function ihb_ResetDefaults
%----------------------------------------------------------------------------------
% FORMAT ihb_ResetDefaults
%----------------------------------------------------------------------------------
% Reset all defaults values to their original defaults
%----------------------------------------------------------------------------------
%   09.04.01    Sergey Pakhomov
%   30.07.01    last modified
%----------------------------------------------------------------------------------
%----------------------------------------------------------------------------------
% Full paths
%----------------------------------------------------------------------------------
dflFileName = ihb_FileFolderName('dfl');
%----------------------------------------------------------------------------------
% Figures tags for windows created by SPM during call spm_getSPM
%----------------------------------------------------------------------------------
ihbdfl_spm_fig_Interactive = 'Interactive';
ihbdfl_spm_fig_SelFileWin = 'SelFileWin';
ihbdfl_spm_fig_ConMan = 'ConMan';
%----------------------------------------------------------------------------------
% Minimal size of clusters to draw
%----------------------------------------------------------------------------------
ihbdfl_min_size_to_draw = 4;
%----------------------------------------------------------------------------------
% Sizes of voxels used in Talariach space
%----------------------------------------------------------------------------------
ihbdfl_tal_x_vox = 2;
ihbdfl_tal_y_vox = 2;
ihbdfl_tal_z_vox = 2;
%----------------------------------------------------------------------------------
% Sizes of main window and axis for ihb_TalSpace
%----------------------------------------------------------------------------------
ihbdfl_main_info_h = 22;
ihbdfl_main_copyright = 2*ihbdfl_main_info_h;
ihbdfl_main_width = 678;
ihbdfl_main_height = 622 + ihbdfl_main_copyright;
ihbdfl_main_gap = 20;
ihbdfl_main_x = 272;
ihbdfl_main_y = 346;
ihbdfl_main_z = 216;
%----------------------------------------------------------------------------------
% Talariach slices information
% AX    - axial (27 slices)
% FR    - frontal (38 slices)
% SL    - saggital left (18 slices)
% SR    - saggital right (18 slices)
%----------------------------------------------------------------------------------
ihbdfl_ax_info = ihb_setAxialInfo;
ihbdfl_fr_info = ihb_setFrontalInfo;
ihbdfl_sl_info = ihb_setLeftSaggitalInfo;
ihbdfl_sr_info = ihb_setRightSaggitalInfo;
%----------------------------------------------------------------------------------
% Axis limits to draw slice
%----------------------------------------------------------------------------------
ihbdfl_xLimD = [ -68 68];
ihbdfl_yLimD = [-103 70];
ihbdfl_zLimD = [ -43 75];
ihbdfl_xLimI = [68  -68];
ihbdfl_yLimI = [70 -103];
ihbdfl_zLimI = [75  -43];
%----------------------------------------------------------------------------------
% 3D view Renderer ('zbuffer' or 'OpenGL') 
% 3D view transparency (available only for OpenGL
% and projection type ('perspective' or 'orthographic')
%----------------------------------------------------------------------------------
ihbdfl_renderer = 'zbuffer';
ihbdfl_transparency = 0.5;
ihbdfl_projection = 'perspective';
%----------------------------------------------------------------------------------
% Axes type for 3D view 
%----------------------------------------------------------------------------------
ihbdfl_bAxesIsClusterOnly = 1;
%----------------------------------------------------------------------------------
% Smoothing parameters for 3D view 
%----------------------------------------------------------------------------------
ihbdfl_bApplySmoothing = 0;
ihbdfl_smooth_filter = 'box';   % 'box' or 'gaussian'
ihbdfl_smooth_size = [3 3 3];
ihbdfl_smooth_sd = 0.65;
%----------------------------------------------------------------------------------
% Colors defaults
%----------------------------------------------------------------------------------
ihbdfl_color_clOrig = [1 0 0];
ihbdfl_color_clSymm = [1 0 1];
ihbdfl_color_surface = [0 0 1];
ihbdfl_color_cntAx = [1 1 1];
ihbdfl_color_cntFr = [0 1 0];
ihbdfl_color_cntSag = [1 1 0];
%----------------------------------------------------------------------------------
% Line width
%----------------------------------------------------------------------------------
ihbdfl_line_width = 2;
%----------------------------------------------------------------------------------
% Save all defaults
%----------------------------------------------------------------------------------
save(dflFileName, 'ihbdfl_*');
%==================================================================================
%   Subfunctions to set information about Talariach slices images
%==================================================================================
%----------------------------------------------------------------------------------
%   Axial slices
%----------------------------------------------------------------------------------
function info = ihb_setAxialInfo;
info = repmat(struct('fileName', '', 'name', '', 'dist', 0), 1, 27);

n = 1;

info(n).fileName = 'm_40.jpg';
info(n).name = 'Axial -40 mm';
info(n).dist = -40;
n = n+1;

info(n).fileName = 'm_36.jpg';
info(n).name = 'Axial -36 mm';
info(n).dist = -36;
n = n+1;

info(n).fileName = 'm_32.jpg';
info(n).name = 'Axial -32 mm';
info(n).dist = -32;
n = n+1;

info(n).fileName = 'm_28.jpg';
info(n).name = 'Axial -28 mm';
info(n).dist = -28;
n = n+1;

info(n).fileName = 'm_24.jpg';
info(n).name = 'Axial -24 mm';
info(n).dist = -24;
n = n+1;

info(n).fileName = 'm_20.jpg';
info(n).name = 'Axial -20 mm';
info(n).dist = -20;
n = n+1;

info(n).fileName = 'm_16.jpg';
info(n).name = 'Axial -16 mm';
info(n).dist = -16;
n = n+1;

info(n).fileName = 'm_12.jpg';
info(n).name = 'Axial -12 mm';
info(n).dist = -12;
n = n+1;

info(n).fileName = 'm_08.jpg';
info(n).name = 'Axial -08 mm';
info(n).dist = -8;
n = n+1;

info(n).fileName = 'm_04.jpg';
info(n).name = 'Axial -04 mm';
info(n).dist = -4;
n = n+1;

info(n).fileName = 'm_01.jpg';
info(n).name = 'Axial -01 mm';
info(n).dist = -1;
n = n+1;

info(n).fileName = 'p_01.jpg';
info(n).name = 'Axial +01 mm';
info(n).dist = 1;
n = n+1;

info(n).fileName = 'p_04.jpg';
info(n).name = 'Axial +04 mm';
info(n).dist = 4;
n = n+1;

info(n).fileName = 'p_08.jpg';
info(n).name = 'Axial +08 mm';
info(n).dist = 8;
n = n+1;

info(n).fileName = 'p_12.jpg';
info(n).name = 'Axial +12 mm';
info(n).dist = 12;
n = n+1;

info(n).fileName = 'p_16.jpg';
info(n).name = 'Axial +16 mm';
info(n).dist = 16;
n = n+1;

info(n).fileName = 'p_20.jpg';
info(n).name = 'Axial +20 mm';
info(n).dist = 20;
n = n+1;

info(n).fileName = 'p_24.jpg';
info(n).name = 'Axial +24 mm';
info(n).dist = 24;
n = n+1;

info(n).fileName = 'p_28.jpg';
info(n).name = 'Axial +28 mm';
info(n).dist = 28;
n = n+1;

info(n).fileName = 'p_32.jpg';
info(n).name = 'Axial +32 mm';
info(n).dist = 32;
n = n+1;

info(n).fileName = 'p_35.jpg';
info(n).name = 'Axial +35 mm';
info(n).dist = 35;
n = n+1;

info(n).fileName = 'p_40.jpg';
info(n).name = 'Axial +40 mm';
info(n).dist = 40;
n = n+1;

info(n).fileName = 'p_45.jpg';
info(n).name = 'Axial +45 mm';
info(n).dist = 45;
n = n+1;

info(n).fileName = 'p_50.jpg';
info(n).name = 'Axial +50 mm';
info(n).dist = 50;
n = n+1;

info(n).fileName = 'p_55.jpg';
info(n).name = 'Axial +55 mm';
info(n).dist = 55;
n = n+1;

info(n).fileName = 'p_60.jpg';
info(n).name = 'Axial +60 mm';
info(n).dist = 60;
n = n+1;

info(n).fileName = 'p_65.jpg';
info(n).name = 'Axial +65 mm';
info(n).dist = 65;
%----------------------------------------------------------------------------------
%   Frontal slices
%----------------------------------------------------------------------------------
function info = ihb_setFrontalInfo;
info = repmat(struct('fileName', '', 'name', '', 'dist', 0), 1, 38);

n = 1;

info(n).fileName = 'cor_m100.jpg';
info(n).name = 'Frontal -100 mm';
info(n).dist = -100;
n = n+1;

info(n).fileName = 'cor_m95.jpg';
info(n).name = 'Frontal -95 mm';
info(n).dist = -95;
n = n+1;

info(n).fileName = 'cor_m90.jpg';
info(n).name = 'Frontal -90 mm';
info(n).dist = -90;
n = n+1;

info(n).fileName = 'cor_m85.jpg';
info(n).name = 'Frontal -85 mm';
info(n).dist = -85;
n = n+1;

info(n).fileName = 'cor_m80.jpg';
info(n).name = 'Frontal -80 mm';
info(n).dist = -80;
n = n+1;

info(n).fileName = 'cor_m75.jpg';
info(n).name = 'Frontal -75 mm';
info(n).dist = -75;
n = n+1;

info(n).fileName = 'cor_m70.jpg';
info(n).name = 'Frontal -70 mm';
info(n).dist = -70;
n = n+1;

info(n).fileName = 'cor_m65.jpg';
info(n).name = 'Frontal -65 mm';
info(n).dist = -65;
n = n+1;

info(n).fileName = 'cor_m60.jpg';
info(n).name = 'Frontal -60 mm';
info(n).dist = -60;
n = n+1;

info(n).fileName = 'cor_m55.jpg';
info(n).name = 'Frontal -55 mm';
info(n).dist = -55;
n = n+1;

info(n).fileName = 'cor_m50.jpg';
info(n).name = 'Frontal -50 mm';
info(n).dist = -50;
n = n+1;

info(n).fileName = 'cor_m45.jpg';
info(n).name = 'Frontal -45 mm';
info(n).dist = -45;
n = n+1;

info(n).fileName = 'cor_m40.jpg';
info(n).name = 'Frontal -40 mm';
info(n).dist = -40;
n = n+1;

info(n).fileName = 'cor_m35.jpg';
info(n).name = 'Frontal -35 mm';
info(n).dist = -35;
n = n+1;

info(n).fileName = 'cor_m32.jpg';
info(n).name = 'Frontal -32 mm';
info(n).dist = -32;
n = n+1;

info(n).fileName = 'cor_m28.jpg';
info(n).name = 'Frontal -28 mm';
info(n).dist = -28;
n = n+1;

info(n).fileName = 'cor_m24.jpg';
info(n).name = 'Frontal -24 mm';
info(n).dist = -24;
n = n+1;

info(n).fileName = 'cor_m20.jpg';
info(n).name = 'Frontal -20 mm';
info(n).dist = -20;
n = n+1;

info(n).fileName = 'cor_m16.jpg';
info(n).name = 'Frontal -16 mm';
info(n).dist = -16;
n = n+1;

info(n).fileName = 'cor_m12.jpg';
info(n).name = 'Frontal -12 mm';
info(n).dist = -12;
n = n+1;

info(n).fileName = 'cor_m08.jpg';
info(n).name = 'Frontal -08 mm';
info(n).dist = -8;
n = n+1;

info(n).fileName = 'cor_m04.jpg';
info(n).name = 'Frontal -04 mm';
info(n).dist = -4;
n = n+1;

info(n).fileName = 'cor_p00.jpg';
info(n).name = 'Frontal  00 mm';
info(n).dist = 0;
n = n+1;

info(n).fileName = 'cor_p04.jpg';
info(n).name = 'Frontal +04 mm';
info(n).dist = 4;
n = n+1;

info(n).fileName = 'cor_p08.jpg';
info(n).name = 'Frontal +08 mm';
info(n).dist = 8;
n = n+1;

info(n).fileName = 'cor_p12.jpg';
info(n).name = 'Frontal +12 mm';
info(n).dist = 12;
n = n+1;

info(n).fileName = 'cor_p16.jpg';
info(n).name = 'Frontal +16 mm';
info(n).dist = 16;
n = n+1;

info(n).fileName = 'cor_p20.jpg';
info(n).name = 'Frontal +20 mm';
info(n).dist = 20;
n = n+1;

info(n).fileName = 'cor_p24.jpg';
info(n).name = 'Frontal +24 mm';
info(n).dist = 24;
n = n+1;

info(n).fileName = 'cor_p28.jpg';
info(n).name = 'Frontal +28 mm';
info(n).dist = 28;
n = n+1;

info(n).fileName = 'cor_p32.jpg';
info(n).name = 'Frontal +32 mm';
info(n).dist = 32;
n = n+1;

info(n).fileName = 'cor_p35.jpg';
info(n).name = 'Frontal +35 mm';
info(n).dist = 35;
n = n+1;

info(n).fileName = 'cor_p40.jpg';
info(n).name = 'Frontal +40 mm';
info(n).dist = 40;
n = n+1;

info(n).fileName = 'cor_p45.jpg';
info(n).name = 'Frontal +45 mm';
info(n).dist = 45;
n = n+1;

info(n).fileName = 'cor_p50.jpg';
info(n).name = 'Frontal +50 mm';
info(n).dist = 50;
n = n+1;

info(n).fileName = 'cor_p55.jpg';
info(n).name = 'Frontal +55 mm';
info(n).dist = 55;
n = n+1;

info(n).fileName = 'cor_p60.jpg';
info(n).name = 'Frontal +60 mm';
info(n).dist = 60;
n = n+1;

info(n).fileName = 'cor_p65.jpg';
info(n).name = 'Frontal +65 mm';
info(n).dist = 65;
%----------------------------------------------------------------------------------
%   Left saggital slices
%----------------------------------------------------------------------------------
function info = ihb_setLeftSaggitalInfo;
info = repmat(struct('fileName', '', 'name', '', 'dist', 0), 1, 18);
n = 1;

info(n).fileName = 'sag_l_00.jpg';
info(n).name = 'Left Saggital  00 mm';
info(n).dist = 0;
n = n+1;

info(n).fileName = 'sag_l_03.jpg';
info(n).name = 'Left Saggital 03 mm';
info(n).dist = -3;
n = n+1;

info(n).fileName = 'sag_l_05.jpg';
info(n).name = 'Left Saggital 05 mm';
info(n).dist = -5;
n = n+1;

info(n).fileName = 'sag_l_09.jpg';
info(n).name = 'Left Saggital 09 mm';
info(n).dist = -9;
n = n+1;

info(n).fileName = 'sag_l_13.jpg';
info(n).name = 'Left Saggital 13 mm';
info(n).dist = -13;
n = n+1;

info(n).fileName = 'sag_l_17.jpg';
info(n).name = 'Left Saggital 17 mm';
info(n).dist = -17;
n = n+1;

info(n).fileName = 'sag_l_21.jpg';
info(n).name = 'Left Saggital 21 mm';
info(n).dist = -21;
n = n+1;

info(n).fileName = 'sag_l_25.jpg';
info(n).name = 'Left Saggital 25 mm';
info(n).dist = -25;
n = n+1;

info(n).fileName = 'sag_l_29.jpg';
info(n).name = 'Left Saggital 29 mm';
info(n).dist = -29;
n = n+1;

info(n).fileName = 'sag_l_33.jpg';
info(n).name = 'Left Saggital 33 mm';
info(n).dist = -33;
n = n+1;

info(n).fileName = 'sag_l_37.jpg';
info(n).name = 'Left Saggital 37 mm';
info(n).dist = -37;
n = n+1;

info(n).fileName = 'sag_l_41.jpg';
info(n).name = 'Left Saggital 41 mm';
info(n).dist = -41;
n = n+1;

info(n).fileName = 'sag_l_43.jpg';
info(n).name = 'Left Saggital 43 mm';
info(n).dist = -43;
n = n+1;

info(n).fileName = 'sag_l_47.jpg';
info(n).name = 'Left Saggital 47 mm';
info(n).dist = -47;
n = n+1;

info(n).fileName = 'sag_l_51.jpg';
info(n).name = 'Left Saggital 51 mm';
info(n).dist = -51;
n = n+1;

info(n).fileName = 'sag_l_55.jpg';
info(n).name = 'Left Saggital 55 mm';
info(n).dist = -55;
n = n+1;

info(n).fileName = 'sag_l_59.jpg';
info(n).name = 'Left Saggital 59 mm';
info(n).dist = -59;
n = n+1;

info(n).fileName = 'sag_l_61.jpg';
info(n).name = 'Left Saggital 61 mm';
info(n).dist = -61;
%----------------------------------------------------------------------------------
%   Right saggital slices
%----------------------------------------------------------------------------------
function info = ihb_setRightSaggitalInfo;
info = repmat(struct('fileName', '', 'name', '', 'dist', 0), 1, 18);
n = 1;

info(n).fileName = 'sag_r_00.jpg';
info(n).name = 'Right Saggital 00 mm';
info(n).dist = 0;
n = n+1;

info(n).fileName = 'sag_r_02.jpg';
info(n).name = 'Right Saggital 02 mm';
info(n).dist = 2;
n = n+1;

info(n).fileName = 'sag_r_04.jpg';
info(n).name = 'Right Saggital 04 mm';
info(n).dist = 4;
n = n+1;

info(n).fileName = 'sag_r_08.jpg';
info(n).name = 'Right Saggital 08 mm';
info(n).dist = 8;
n = n+1;

info(n).fileName = 'sag_r_10.jpg';
info(n).name = 'Right Saggital 10 mm';
info(n).dist = 10;
n = n+1;

info(n).fileName = 'sag_r_16.jpg';
info(n).name = 'Right Saggital 16 mm';
info(n).dist = 16;
n = n+1;

info(n).fileName = 'sag_r_20.jpg';
info(n).name = 'Right Saggital 20 mm';
info(n).dist = 20;
n = n+1;

info(n).fileName = 'sag_r_24.jpg';
info(n).name = 'Right Saggital 24 mm';
info(n).dist = 24;
n = n+1;

info(n).fileName = 'sag_r_28.jpg';
info(n).name = 'Right Saggital 28 mm';
info(n).dist = 28;
n = n+1;

info(n).fileName = 'sag_r_30.jpg';
info(n).name = 'Right Saggital 30 mm';
info(n).dist = 30;
n = n+1;

info(n).fileName = 'sag_r_34.jpg';
info(n).name = 'Right Saggital 34 mm';
info(n).dist = 34;
n = n+1;

info(n).fileName = 'sag_r_38.jpg';
info(n).name = 'Right Saggital 38 mm';
info(n).dist = 38;
n = n+1;

info(n).fileName = 'sag_r_42.jpg';
info(n).name = 'Right Saggital 42 mm';
info(n).dist = 42;
n = n+1;

info(n).fileName = 'sag_r_46.jpg';
info(n).name = 'Right Saggital 46 mm';
info(n).dist = 46;
n = n+1;

info(n).fileName = 'sag_r_50.jpg';
info(n).name = 'Right Saggital 50 mm';
info(n).dist = 50;
n = n+1;

info(n).fileName = 'sag_r_54.jpg';
info(n).name = 'Right Saggital 54 mm';
info(n).dist = 54;
n = n+1;

info(n).fileName = 'sag_r_58.jpg';
info(n).name = 'Right Saggital 58 mm';
info(n).dist = 58;
n = n+1;

info(n).fileName = 'sag_r_62.jpg';
info(n).name = 'Right Saggital 62 mm';
info(n).dist = 62;
n = n+1;
